% runMCMCandContour.m 
% This script runs DRAM code and calls code to make contour plot of energy. 
% It also creates a folder, 'results1/folder/' where results from DRAM and
% contour are stored. Format for name of 'folder' is 'month_date_time'
% The most frequently changed parameters are edited here
%
% C. Lichten, University of Edinburgh, 2010
% http://swainlab.bio.ed.ac.uk/software.php

addpath('utils/');
addpath('utils/mcmcstat/');

%% 1. FREQUENTLY EDITED PARAMETERS FOR MCMC RANDOM WALK: *********

cv= .02; % STEPSIZE (decrease if acceptance rate is low)
startingValues= [.5 -3]; % Starting location for [Efr, log10(Kd)]
vary_all= -1; % options: -1,0 (search Kd-Efr, from startingValues or random location); 
                       % 1,2 (search all params, begin at sV or random for Efr-KD)
NumSteps= 1e4; % make > 1000

% Prior Information (mean and std) you choose/edit: 
 parmu0= []; parsig0= []; % no prior information
% parmu0= [.45 1]; parsig0= [.15 1e4]; % Prior= Efr=.45.15
% parmu0= [.4 -5 reshape(cparams,1,9)]; parsig0= [1e4 1e4 2e-3*ones(1,9)]; % Prior: aij=aij.002
% NOTE: parmu0 and parsig0 should be length 2 for vary_all =-1,0.
% otherwise, they should be length 11

%% 
% 2. Make dir where results will be saved
c=clock;
dirname=sprintf('results1/%2.0f_%2.0f_%2.0fh%02.0f/',c(2:5));
mkdir(dirname)
save([dirname,'data_used'],'datasim');
clear DRAMresults*

%3. Run MCMC biased random walk
data= datasim; % analyze all data together
find_kdefr  

% 4. Generate contour of energy
makeContour

% 5. Save results
DRAMresults.enrgcon= enrgcon;
DRAMresults.Efr= Efr;   DRAMresults.log10kd= log10kd;
save([dirname,'DRAMresults_altogether'],'DRAMresults');

% 6. Plot results
ShowFigures(DRAMresults,datasim)
