function handles = barerr(barvalues, errors, width, varargin)
% function handles = barerr(barvalues, errors, width)

% Original Author: Bolu Ajiboye


% Get function arguments
if nargin < 2
    error('Must have at least the first two arguments:  barweb(barvalues, errors, width, groupnames, bw_title, bw_xlabel, bw_ylabel, bw_colormap, gridstatus, bw_legend)');
elseif nargin == 2
    width = 0.8;
end;


if size(barvalues,1) ~= size(errors,1) || size(barvalues,2) ~= size(errors,2)

    error('barvalues and errors matrix must be of same dimension');

else

    if size(barvalues,2) == 1
        barvalues = barvalues';
        errors = errors';
    end;

    % plot bars and errors
    clf;
    handles.bars = bar(barvalues, width, varargin{:});
    hold on;
    if size(barvalues,1) == 1
        % just one group
        handles.errors= errorbar([1:size(barvalues,2)], barvalues, ...
            errors, 'k', 'linestyle', 'none');
    else
        % many groups
        numbars = size(barvalues, 2); % number of bars in a group
        numgroups = size(barvalues, 1); % number of groups
        groupwidth = min(0.8, numbars/(numbars+1.5));
        for i = 1:numbars
            x = (1:numgroups) - groupwidth/2 ...
                + (2*i-1)*groupwidth/(2*numbars);
            handles.errors(i) = errorbar(x, barvalues(:,i), ...
                errors(:,i), 'k', 'linestyle', 'none');
        end;
        set(gcf, 'color', 'white');
    end;

    handles.ca = gca;
    hold off;
end
